"""
umd-python-cas
A python client to access the University of Maryland Central Authentication Services (CAS) remote instance.
"""

__version__ = "1.0.1"
__author__ = 'Jacob (Coby) Winfield & Johan Vandegriff'
__credits__ = 'Daniel Laurence & Jim Purtilo & Ronel Aguilar'

from umd_python_cas.umd_python_cas import UMDCASClient
